<?php
// Set the path for the uploads folder. (업로드 폴더의 경로 설정.)
require_once('wp-load.php');

// Number of images to display per page. (한 페이지에 표시할 이미지 개수.)
$uploads_dir = wp_upload_dir()['basedir'];
$images_per_page = 1000;

// Get the current page. (현재 페이지 가져오기.)
$current_page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;

// Get a list of all image files. (모든 이미지 파일 목록 가져오기.)
$all_images = glob($uploads_dir . '/*/*/*.{jpg,jpeg,png,gif}', GLOB_BRACE);

// Get all posts. (모든 포스트 가져오기.)
$args = array(
    'post_type' => array('post', 'page'), // Search for both posts and pages. (포스트와 페이지 모두 검색.)
    'posts_per_page' => -1,
);
$posts = get_posts($args);

// Get all pages. (모든 페이지 가져오기.)
$pages = get_pages(array('sort_column' => 'post_date', 'sort_order' => 'desc'));

// Combine posts and pages. (포스트와 페이지 결합.)
$all_posts = array_merge($posts, $pages);

// Crop the list of visible images based on the current page. (현재 페이지에 맞게 이미지 리스트 자르기.)
$start_index = ($current_page - 1) * $images_per_page;
$visible_images = array_slice($all_images, $start_index, $images_per_page);

// Image deletion handling. (이미지 삭제 처리.)
if (isset($_POST['delete_images'])) {
    $selected_images = $_POST['delete_images'];
    foreach ($selected_images as $selected_image) {
        // Delete the image file. (이미지 파일 삭제.)
        unlink($uploads_dir . $selected_image);
    }
    // Reload the page. (페이지 리로드.)
    echo '<meta http-equiv="refresh" content="0"/>';
}

// Output: Image list (출력: 이미지 목록)
echo '<h1>Image List (이미지 목록)</h1>';
echo '<form method="post">';
echo '<ul>';
foreach ($visible_images as $image) {
    // Extract the relative path of the image file. (이미지 파일의 상대 경로 추출.)
    $relative_path = str_replace($uploads_dir, '', $image);
    // Extract only the image file name. (이미지 파일명만 추출.)
    $image_name = pathinfo($image, PATHINFO_BASENAME);
    // Check if the image file has been used in any post or page. (해당 이미지 파일이 포스트 또는 페이지에서 사용되었는지 확인.)
    $is_used = false;
    foreach ($all_posts as $post) {
        // Get post content. (포스트 내용 가져오기.)
        $content = $post->post_content;
        // Check if the image file name exists in the post content. (이미지 파일명이 포스트 내용에 존재하는지 확인.)
        if (strpos($content, $image_name) !== false) {
            $is_used = true;
            break;
        }
    }
    // Output and specify color. (출력 및 컬러 지정.)
    $color = $is_used ? 'blue' : 'black';
    // Set default checkbox state to checked only for images that are not in use. (이미지가 사용되지 않은 경우에만 체크박스 기본 체크 상태로 설정.)
    $checked = !$is_used ? 'checked' : ''; 
    echo '<li style="color: ' . $color . ';">' . $image_name . ' - ' . $relative_path . ' ';
    echo '<input type="checkbox" name="delete_images[]" value="' . $relative_path . '" ' . $checked . '/></li>';
}
echo '</ul>';

// Output delete button and pagination bar. (삭제 버튼 및 페이징바 출력.)
echo '<input type="submit" value="Delete Selected Images(선택한 이미지 삭제)"/>';
echo '</form>';
echo '<div class="pagination">';
for ($i = 1; $i <= ceil(count($all_images) / $images_per_page); $i++) {
    echo '<a href="?page=' . $i . '">' . $i . '</a>';
}
echo '</div>';
?>